@@ -251,7 +251,7 @@ class ScaLAPACK4py:
     descr = self.wrap_blacs_desc(descr)
     data = np.ctypeslib.as_array(data, shape=(descr.locrow, descr.loccol)).T
     res = np.zeros(shape, dtype=np.float64).T if (descr.myrow==0 and descr.mycol==0) else None
-    self.basic_gather(descr, data, res)
+    self.gather(descr, data, res)
     return res
 
   def scatter_numpy(self, src, descr, dst):
@@ -271,7 +271,7 @@ class ScaLAPACK4py:
 
     descr = self.wrap_blacs_desc(descr)
     dst = np.ctypeslib.as_array(dst, shape=(descr.locrow, descr.loccol)).T
-    self.basic_scatter(src, descr, dst)
+    self.scatter(src, descr, dst)
 
   def is_root(self, descr):
     '''
